package de.szut.lf8_starter.integration.project;

import de.szut.lf8_starter.project.ProjectEntity;
import de.szut.lf8_starter.project.ProjectRepository;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.web.servlet.MockMvc;

import java.time.LocalDate;
import java.util.List;

import static org.hamcrest.collection.IsCollectionWithSize.hasSize;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.jsonPath;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;

@SpringBootTest
@AutoConfigureMockMvc(addFilters = false)
class FindProjectActionTest {
    @Autowired
    private MockMvc mockMvc;
    @Autowired
    private ProjectRepository projectRepository;

    @Test
    void createProjectTest() throws Exception {
        var project = new ProjectEntity();
        project.setId(1);
        project.setComment("comment");
        project.setContractor(1);
        project.setContractorName("contractorName");
        project.setEndDate(LocalDate.of(2024, 1, 1));
        project.setLeadingEmployee(1);
        project.setName("name");
        project.setStartDate(LocalDate.of(2021, 1, 1));
        project.setEmployees(List.of(1L, 2L, 3L));
        this.projectRepository.save(project);

        this.mockMvc.perform(get("/projects/1"))
                .andExpect(status().isOk())
                .andExpect(jsonPath("id").value(1))
                .andExpect(jsonPath("comment").value("comment"))
                .andExpect(jsonPath("contractor").value(1))
                .andExpect(jsonPath("contractor_name").value("contractorName"))
                .andExpect(jsonPath("end_date").value("01.01.2024"))
                .andExpect(jsonPath("leading_employee").value(1))
                .andExpect(jsonPath("name").value("name"))
                .andExpect(jsonPath("start_date").value("01.01.2021"))
                .andExpect(jsonPath("employees").isArray())
                .andExpect(jsonPath("employees", hasSize(3)));
    }
}
